# generated by ./ubuntubuild.sh
from distutils.core import setup

setup(
    name='sciproc',
    version='0.6.6',
    author='H. Wouters',
    author_email='hendrikwout@gmail.com',
    packages=['sciproc'],
    url='http://www.nowebsite.com',
    license='LICENSE.txt',
    description='Process scientific multidimensional data.',
    long_description=open('README.txt').read(),
)

